@@ -1,6 +1,3 @@
-extern crate bsdiff;
-extern crate libc;
-
 use bsdiff::patch;
 use bsdiff::diff;
 
@@ -44,4 +41,4 @@ fn test_too_small() {
     let error = patch::patch(&one, &mut cursor, &mut patched).unwrap_err();
 
     assert_eq!(error.kind(), ErrorKind::UnexpectedEof);
-}
\ No newline at end of file
+}
